==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/ListMetaFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ListMetaFluentImpl<A extends ListMetaFluent<A>> extends BaseFluent<A> implements ListMetaFluent<A>{
  public ListMetaFluentImpl() {
  }
  public ListMetaFluentImpl(ListMeta instance) {
    this.withContinue(instance.getContinue()); 
    this.withRemainingItemCount(instance.getRemainingItemCount()); 
    this.withResourceVersion(instance.getResourceVersion()); 
    this.withSelfLink(instance.getSelfLink()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String _continue;
  private Long remainingItemCount;
  private String resourceVersion;
  private String selfLink;
  private Map<String,Object> additionalProperties;
  public String getContinue() {
    return this._continue;
  }
  public A withContinue(String _continue) {
    this._continue=_continue; return (A) this;
  }
  public Boolean hasContinue() {
    return this._continue != null;
  }
  public Long getRemainingItemCount() {
    return this.remainingItemCount;
  }
  public A withRemainingItemCount(Long remainingItemCount) {
    this.remainingItemCount=remainingItemCount; return (A) this;
  }
  public Boolean hasRemainingItemCount() {
    return this.remainingItemCount != null;
  }
  public String getResourceVersion() {
    return this.resourceVersion;
  }
  public A withResourceVersion(String resourceVersion) {
    this.resourceVersion=resourceVersion; return (A) this;
  }
  public Boolean hasResourceVersion() {
    return this.resourceVersion != null;
  }
  public String getSelfLink() {
    return this.selfLink;
  }
  public A withSelfLink(String selfLink) {
    this.selfLink=selfLink; return (A) this;
  }
  public Boolean hasSelfLink() {
    return this.selfLink != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ListMetaFluentImpl that = (ListMetaFluentImpl) o;
    if (_continue != null ? !_continue.equals(that._continue) :that._continue != null) return false;
    if (remainingItemCount != null ? !remainingItemCount.equals(that.remainingItemCount) :that.remainingItemCount != null) return false;
    if (resourceVersion != null ? !resourceVersion.equals(that.resourceVersion) :that.resourceVersion != null) return false;
    if (selfLink != null ? !selfLink.equals(that.selfLink) :that.selfLink != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(_continue,  remainingItemCount,  resourceVersion,  selfLink,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_continue != null) { sb.append("_continue:"); sb.append(_continue + ","); }
    if (remainingItemCount != null) { sb.append("remainingItemCount:"); sb.append(remainingItemCount + ","); }
    if (resourceVersion != null) { sb.append("resourceVersion:"); sb.append(resourceVersion + ","); }
    if (selfLink != null) { sb.append("selfLink:"); sb.append(selfLink + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/ListMetaFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ListMetaFluentImpl<A extends ListMetaFluent<A>> extends BaseFluent<A> implements ListMetaFluent<A>{
  public ListMetaFluentImpl() {
  }
  public ListMetaFluentImpl(ListMeta instance) {
    if (instance != null) {
      this.withContinue(instance.getContinue());
      this.withRemainingItemCount(instance.getRemainingItemCount());
      this.withResourceVersion(instance.getResourceVersion());
      this.withSelfLink(instance.getSelfLink());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String _continue;
  private Long remainingItemCount;
  private String resourceVersion;
  private String selfLink;
  private Map<String,Object> additionalProperties;
  public String getContinue() {
    return this._continue;
  }
  public A withContinue(String _continue) {
    this._continue=_continue; return (A) this;
  }
  public Boolean hasContinue() {
    return this._continue != null;
  }
  public Long getRemainingItemCount() {
    return this.remainingItemCount;
  }
  public A withRemainingItemCount(Long remainingItemCount) {
    this.remainingItemCount=remainingItemCount; return (A) this;
  }
  public Boolean hasRemainingItemCount() {
    return this.remainingItemCount != null;
  }
  public String getResourceVersion() {
    return this.resourceVersion;
  }
  public A withResourceVersion(String resourceVersion) {
    this.resourceVersion=resourceVersion; return (A) this;
  }
  public Boolean hasResourceVersion() {
    return this.resourceVersion != null;
  }
  public String getSelfLink() {
    return this.selfLink;
  }
  public A withSelfLink(String selfLink) {
    this.selfLink=selfLink; return (A) this;
  }
  public Boolean hasSelfLink() {
    return this.selfLink != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ListMetaFluentImpl that = (ListMetaFluentImpl) o;
    if (!java.util.Objects.equals(_continue, that._continue)) return false;

    if (!java.util.Objects.equals(remainingItemCount, that.remainingItemCount)) return false;

    if (!java.util.Objects.equals(resourceVersion, that.resourceVersion)) return false;

    if (!java.util.Objects.equals(selfLink, that.selfLink)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(_continue,  remainingItemCount,  resourceVersion,  selfLink,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_continue != null) { sb.append("_continue:"); sb.append(_continue + ","); }
    if (remainingItemCount != null) { sb.append("remainingItemCount:"); sb.append(remainingItemCount + ","); }
    if (resourceVersion != null) { sb.append("resourceVersion:"); sb.append(resourceVersion + ","); }
    if (selfLink != null) { sb.append("selfLink:"); sb.append(selfLink + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
